use skytable::{
	query::SQParam,
	response::{
		FromResponse,
		Response,
		Value,
	},
	ClientResult,
};


pub struct Users {
	pub uuid: String,
	pub login: String,
	pub password: String,
	pub email: String,
	pub tokens: Vec<Value>,
}

impl Users {
	pub fn new(uuid: String, login: String, password: String, email: String, tokens: Vec<Value>) -> Self {
		Self {
			uuid,
			login,
			password,
			email,
			tokens,
		}
	}
}

impl SQParam for Users {
	fn append_param(&self, q: &mut Vec<u8>) -> usize {
		self.uuid.append_param(q)
			+ self.login.append_param(q)
			+ self.password.append_param(q)
			+ self.email.append_param(q)
	}
}

impl FromResponse for Users {
	fn from_response(resp: Response) -> ClientResult<Self> {
		let (uuid, login, password, email, tokens) = FromResponse::from_response(resp)?;
		Ok(Self::new(uuid, login, password, email, tokens))
	}
}
