use {
	hyper::{
		StatusCode,
		Request,
		Method,
		HeaderMap,
		header::HeaderValue,
		body::{
			Incoming,
		},
	},
	urlencoding::{
		decode as url_decode,
	},
	crate::{
		Result,
		DBPool,
		html::*,
		funcs::*,
	},
};


pub async fn login(req: Request<Incoming>, pool: DBPool, headers: &mut HeaderMap) -> Result<(String, StatusCode, HeaderValue)> {
	let mut body = build_html(LOGIN_HTML);
	let mut status = StatusCode::OK;
	let restype: HeaderValue = "text/html".parse().unwrap();

	if *req.method() == Method::POST {
		let r = double_split(req.uri().query().or(Some("")).unwrap().to_owned(), "&", "=");

		let post = get_body_from_request(req).await?;
		let post = String::from_utf8(post).unwrap();
		let post = double_split(post, "&", "=");

		let (access, refresh) = login_user(pool.clone(), post).await?;

		set_cookie(headers, "token", &access);
		set_cookie(headers, "refresh", &refresh);

		let r = r.get("q");
		match r.is_some() {
			true => {
				status = StatusCode::FOUND;
				body = "".to_owned();
				set_location(headers, format!("{}", url_decode(r.unwrap())?).as_str());
			},
			_ => {}
		}
	}

	Ok((body, status, restype))
}
